@@ -7,6 +7,7 @@ from contextlib import contextmanager
 
 from lxml.cssselect import CSSSelector
 from selenium.common.exceptions import NoSuchElementException
+from selenium.webdriver.common.action_chains import ActionChains
 
 from splinter.driver import DriverAPI, ElementAPI
 from splinter.element_list import ElementList
@@ -127,6 +128,12 @@ class BaseWebDriver(DriverAPI):
     def is_element_not_present_by_name(self, name, wait_time=None):
         return self.is_element_not_present(self.find_by_name, name, wait_time)
 
+    def is_element_present_by_value(self, value, wait_time=None):
+        return self.is_element_present(self.find_by_value, value, wait_time)
+
+    def is_element_not_present_by_value(self, value, wait_time=None):
+        return self.is_element_not_present(self.find_by_value, value, wait_time)
+
     def is_element_present_by_id(self, id, wait_time=None):
         return self.is_element_present(self.find_by_id, id, wait_time)
 
@@ -168,21 +175,31 @@ class BaseWebDriver(DriverAPI):
             self.driver.switch_to_frame(None)
 
     def find_option_by_value(self, value):
-        return self.find_by_xpath('//option[@value="%s"]' % value)
+        return self.find_by_xpath('//option[@value="%s"]' % value, original_find="option by value", original_query=value)
 
     def find_option_by_text(self, text):
-        return self.find_by_xpath('//option[normalize-space(text())="%s"]' % text)
+        return self.find_by_xpath('//option[normalize-space(text())="%s"]' % text, original_find="option by text", original_query=text)
 
     def find_link_by_href(self, href):
-        return self.find_by_xpath('//a[@href="%s"]' % href)
+        return self.find_by_xpath('//a[@href="%s"]' % href, original_find="link by href", original_query=href)
+
+    def find_link_by_partial_href(self, partial_href):
+        return self.find_by_xpath('//a[contains(@href, "%s")]' % partial_href, original_find="link by partial href", original_query=partial_href)
+
+    def find_link_by_partial_text(self, partial_text):
+        return ElementList([self.element_class(element, self) for element in self.driver.find_elements_by_partial_link_text(partial_text)], find_by="partial text", query=partial_text)
 
     def find_link_by_text(self, text):
-        return ElementList([self.element_class(element, self) for element in self.driver.find_elements_by_link_text(text)])
+        return ElementList([self.element_class(element, self) for element in self.driver.find_elements_by_link_text(text)], find_by="link by text", query=text)
 
-    def find_by(self, finder, selector):
+    def find_by(self, finder, selector, original_find=None, original_query=None):
         elements = None
         end_time = time.time() + self.wait_time
 
+        func_name = finder.im_func.func_name
+        find_by = original_find or func_name[func_name.rfind('_by_') + 4:]
+        query = original_query or selector
+
         while time.time() < end_time:
             try:
                 elements = finder(selector)
@@ -192,17 +209,19 @@ class BaseWebDriver(DriverAPI):
                 pass
 
             if elements:
-                return ElementList([self.element_class(element, self) for element in elements])
-        return ElementList([])
+                return ElementList([self.element_class(element, self) for element in elements], find_by=find_by, query=query)
+        return ElementList([], find_by=find_by, query=query)
 
     def find_by_css(self, css_selector):
         selector = CSSSelector(css_selector)
-        return self.find_by(self.driver.find_elements_by_xpath, selector.path)
+        return self.find_by(self.driver.find_elements_by_xpath, selector.path, original_find='css', original_query=css_selector)
 
     find_by_css_selector = warn_deprecated(find_by_css, 'find_by_css_selector')
 
-    def find_by_xpath(self, xpath):
-        return self.find_by(self.driver.find_elements_by_xpath, xpath)
+    def find_by_xpath(self, xpath, original_find=None, original_query=None):
+        original_find = original_find or "xpath"
+        original_query = original_query or xpath
+        return self.find_by(self.driver.find_elements_by_xpath, xpath, original_find=original_find, original_query=original_query)
 
     def find_by_name(self, name):
         return self.find_by(self.driver.find_elements_by_name, name)
@@ -210,6 +229,9 @@ class BaseWebDriver(DriverAPI):
     def find_by_tag(self, tag):
         return self.find_by(self.driver.find_elements_by_tag_name, tag)
 
+    def find_by_value(self, value):
+        return self.find_by_xpath('//*[@value="%s"]' % value, original_find='value', original_query=value)
+
     def find_by_id(self, id):
         return self.find_by(self.driver.find_element_by_id, id)
 
@@ -220,6 +242,13 @@ class BaseWebDriver(DriverAPI):
     fill_in = warn_deprecated(fill, 'fill_in')
     attach_file = fill
 
+    def type(self, name, value, slowly=False):
+        element = self.driver.find_element_by_css_selector('input[name="%s"]' % name)
+        if slowly:
+            return TypeIterator(element, value)
+        element.send_keys(value)
+        return value
+
     def choose(self, name, value):
         fields = self.find_by_name(name)
         for field in fields:
@@ -246,11 +275,25 @@ class BaseWebDriver(DriverAPI):
         return self._cookie_manager
 
 
+class TypeIterator(object):
+
+
+    def __init__(self, element, keys):
+        self._element = element
+        self._keys = keys
+
+    def __iter__(self):
+        for key in self._keys:
+            self._element.send_keys(key)
+            yield key
+
+
 class WebDriverElement(ElementAPI):
 
     def __init__(self, element, parent):
         self._element = element
         self.parent = parent
+        self.action_chains = ActionChains(parent.driver)
 
     def _get_value(self):
         value = self["value"]
@@ -290,25 +333,50 @@ class WebDriverElement(ElementAPI):
     def visible(self):
         return self._element.is_displayed()
 
-    def find_by_css(self, selector):
+    def find_by_css(self, selector, original_find=None, original_query=None):
+        find_by = original_find or 'css'
+        query = original_query or selector
+
         elements = self._element.find_elements_by_css_selector(selector)
-        return ElementList([self.__class__(element, self) for element in elements])
+        return ElementList([self.__class__(element, self.parent) for element in elements], find_by=find_by, query=query)
 
     def find_by_xpath(self, selector):
         elements = ElementList(self._element.find_elements_by_xpath(selector))
-        return ElementList([self.__class__(element, self) for element in elements])
+        return ElementList([self.__class__(element, self.parent) for element in elements], find_by='xpath', query=selector)
 
     def find_by_name(self, name):
         elements = ElementList(self._element.find_elements_by_name(name))
-        return ElementList([self.__class__(element, self) for element in elements])
+        return ElementList([self.__class__(element, self.parent) for element in elements], find_by='name', query=name)
 
     def find_by_tag(self, tag):
         elements = ElementList(self._element.find_elements_by_tag_name(tag))
-        return ElementList([self.__class__(element, self) for element in elements])
+        return ElementList([self.__class__(element, self.parent) for element in elements], find_by='tag', query=tag)
+
+    def find_by_value(self, value):
+        selector = '[value="%s"]' % value
+        return self.find_by_css(selector, original_find='value', original_query=value)
 
     def find_by_id(self, id):
         elements = ElementList(self._element.find_elements_by_id(id))
-        return ElementList([self.__class__(element, self) for element in elements])
+        return ElementList([self.__class__(element, self.parent) for element in elements], find_by='id', query=id)
+
+    def mouseover(self):
+        """
+        Performs a mouse over the element.
+
+        Currently works only on Chrome driver.
+        """
+        self.action_chains.move_to_element(self._element)
+        self.action_chains.perform()
+
+    def mouseout(self):
+        """
+        Performs a mouse out the element.
+
+        Currently works only on Chrome driver.
+        """
+        self.action_chains.move_by_offset(5000, 5000)
+        self.action_chains.perform()
 
     def __getitem__(self, attr):
         return self._element.get_attribute(attr)
@@ -334,3 +402,4 @@ class AlertElement(object):
 
     def __exit__(self, type, value, traceback):
         pass
+
