@@ -2,7 +2,7 @@
 
 from selenium.webdriver import Chrome
 from splinter.driver.webdriver import BaseWebDriver, WebDriverElement
-from splinter.driver.webdriver.cookie_manager import CookieManager
+from splinter.driver.webdriver.cookie_manager import ChromeCookieManager
 
 
 class WebDriver(BaseWebDriver):
@@ -13,12 +13,18 @@ class WebDriver(BaseWebDriver):
 
         self.element_class = WebDriverElement
 
-        self._cookie_manager = CookieManager(self.driver)
+        self._cookie_manager = ChromeCookieManager(self.driver)
 
         super(WebDriver, self).__init__()
 
     def attach_file(self, name, value):
+        """
+        Chrome doesn't have support for file uploading.
+        """
         raise NotImplementedError
 
     def get_alert(self):
+        """
+        Chrome doesn't have support for alerts.
+        """
         raise NotImplementedError
